%MACRO use_metadata(indsn=, outdsn=, table=, debug=N);
  * Create a catalog source member to store the programs *;
  FILENAME src CATALOG "work.meta_&table.";
  ** Extract the variable metadata from source_columns **;
  DATA _NULL_;
    SET metadata.source_columns;
    WHERE table = "%upcase(&table.)";
    LENGTH _label _format _length $200;
    FILE src(columns.source);
    IF _N_ = 1 THEN PUT "KEEP=" column;
    ELSE PUT " " column;
    FILE src(attrib.source);
    _label = STRIP(label);
    _format = STRIP(displayformat);
    _length = STRIP(PUT(length, 8.));
    PUT "ATTRIB " column;
    IF CMISS(_label) = 0 THEN
      PUT " LABEL='" _label +(-1) "'";
    IF CMISS(_format) = 0 THEN PUT " FORMAT=" _format;
    IF type = "C" AND NMISS(length) = 0 THEN
      PUT " LENGTH=$" _length;
    PUT " ;";
    FILE src(initial.source);
    PUT column "= " column ";";
  RUN;
  ** Extract the data set metadata from source_tables **;
  DATA _NULL_;
    SET metadata.source_tables;
    WHERE table = "%upcase(&table.)";
    LENGTH _label $200;
    FILE src(dslabel.source);
    _label = STRIP(label);
    PUT " (LABEL='" _label +(-1) "');";
    FILE src(sort.source);
    PUT keys ";";
  RUN;
  ** Update the input data set with the metadata **;
  DATA &indsn._a (
    %INCLUDE src(columns.source);
                );
    %INCLUDE src(attrib.source);
    SET &indsn.;
    BY studyid usubjid paramcd adt qsseq;
    %INCLUDE src(initial.source);
  RUN;
  ** Create the ADaM data set with the correct sorting **;
  PROC SORT DATA = &indsn._a
            OUT = &outdsn.
    %INCLUDE src(dslabel.source);;
    BY %INCLUDE src(sort.source);
  RUN;
  ** Compare with &table in ADAM_CST **;
  PROC COMPARE BASE=adam_cst.&table. COMPARE=&outdsn.
               LISTALL BRIEFSUMMARY MAXPRINT=(5000, 100)
               METHOD=RELATIVE CRITERION=0.001;
    ID %INCLUDE src(sort.source);
  RUN;
  ** Delete temporary data sets, if not debugging **;
  %if %upcase(&debug.) NE N %then %do;
    PROC DATASETS LIB = work;
      DELETE &indsn._a;
    RUN;
    QUIT;
  %end;
%MEND use_metadata;