PROC GPLOT DATA = sashelp9.class;
    SYMBOL V = CIRCLE I = NONE;
    PLOT weight * height = sex;
RUN;

*-------------------------------------------------*;

PROC SGPLOT DATA = sashelp9.class;
    SCATTER Y = weight X = height
            / GROUP = sex;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex height;
RUN;

PROC GPLOT DATA = class;
    SYMBOL V = CIRCLE I = JOIN;
    PLOT weight * height = sex;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex height;
RUN;

PROC SGPLOT DATA = class;
    SERIES Y = weight X = height
           / GROUP = sex MARKERS
             MARKERATTRS = (SYMBOL=CIRCLE);
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex height;
RUN;

PROC GPLOT DATA = class;
    SYMBOL V = CIRCLE I = R /*R0CLI95*/;
    PLOT weight * height = sex;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex height;
RUN;

PROC SGPLOT DATA = class;
    REG Y = weight X = height
        / GROUP = sex CLI
          MARKERATTRS = (SYMBOL=CIRCLE);
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class OUT = class_error;
    BY sex height;
RUN;

PROC SUMMARY DATA = class_error NWAY;
    CLASS sex;
    VAR weight;
    OUTPUT OUT = class_error_se STDERR = weight_se;
RUN;

DATA class_error_classic (KEEP = sex height value)
     class_error_ods
      (KEEP = sex height value value_upper value_lower);
    MERGE class_error class_error_se;
    BY sex;
    value = weight;
    value_upper = value + weight_se;
    value_lower = value - weight_se;
    OUTPUT class_error_ods;
    OUTPUT class_error_classic;
    value = value_upper;
    OUTPUT class_error_classic;
    value = value_lower;
    OUTPUT class_error_classic;
RUN;

%LET height_offset = 0.3;

DATA class_error_anno;
    SET class_error_ods;
    BY sex;
    LENGTH function $8
           color $20
           when xsys ysys $1
           x y 8
           ;
    xsys = '2';
    ysys = '2';
    when = 'A';
    IF sex = 'M' THEN color = 'RED';
    ELSE color = 'BLUE';
    function = 'MOVE';
    x = height - &height_offset.;
    y = value_upper;
    OUTPUT;
    function = 'DRAW';
    x = height + &height_offset.;
    y = value_upper;
    OUTPUT;
    function = 'MOVE';
    x = height;
    y = value_upper;
    OUTPUT;
    function = 'DRAW';
    x  height;
    y = value_lower;
    OUTPUT;
    function = 'MOVE';
    x = height - &height_offset.;
    y = value_lower;
    OUTPUT;
    function = 'DRAW';
    x = height + &height_offset.;
    y = value_lower;
    OUTPUT;
RUN;

PROC GPLOT DATA = class_error ANNOTATE = class_error_anno;
    SYMBOL V = CIRCLE I = JOIN;
    PLOT weight * height = sex / VAXIS = 40 TO 160 BY 10;
    LABEL weight = "Weight";
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class OUT = class_error;
    BY sex height;
RUN;

PROC SUMMARY DATA = class_error NWAY;
    CLASS sex;
    VAR weight;
    OUTPUT OUT = class_error_se STDERR = weight_se;
RUN;

DATA class_error_ods
       (KEEP = sex height value value_upper value_lower);
    MERGE class_error class_error_se;
    BY sex;
    value = weight;
    value_upper = value + weight_se;
    value_lower = value - weight_se;
RUN;

PROC SGPLOT DATA = class_error_ods;
    SCATTER Y = value X = height
            / GROUP = sex YERRORUPPER = value_upper
              YERRORLOWER = value_lower;
    SERIES Y = value X = height / GROUP = sex;
    LABEL value = "Weight";
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY age;
RUN;

PROC GPLOT DATA = class;
    SYMBOL V = CIRCLE I = NONE /*BOX00T*/;
    PLOT height * age;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY age;
RUN;

PROC SGPLOT DATA = class;
    VBOX height / CATEGORY = age;
RUN;

*-------------------------------------------------*;

PROC GCHART DATA = sashelp9.class;
    TITLE "PROC GCHART: Simple vertical barchart of CLASS";
    VBAR age / DISCRETE;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC SGPLOT DATA = class;
    TITLE "PROC SGPLOT: Simple vertical barchart of CLASS";
    VBAR age;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC GCHART DATA = class;
    TITLE "PROC GCHART: Stacked vertical barchart of CLASS";
    VBAR age / SUBGROUP = sex DISCRETE;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC SGPLOT DATA = class;
    TITLE "PROC SGPLOT: Stacked vertical barchart of CLASS";
    VBAR age / GROUP = sex;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC GCHART DATA = class;
    TITLE "PROC GCHART: Clustered vertical barchart of
           CLASS";
    VBAR sex / GROUP = age
               PATTERNID = MIDPOINT;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC SGPLOT DATA = class;
    TITLE
      "PROC SGPLOT: Clustered vertical barchart of CLASS";
    VBAR age / GROUP = sex
               GROUPDISPLAY = CLUSTER;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC GCHART DATA = class;
    TITLE
      "PROC GCHART: Simple horizontal barchart of CLASS";
    HBAR age / DISCRETE;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC SGPLOT DATA = class;
    TITLE
      "PROC SGPLOT: Simple horizontal barchart of CLASS";
    HBAR age;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC GCHART DATA = class;
    TITLE
      "PROC GCHART: Stacked horizontal barchart of CLASS";
    HBAR age / SUBGROUP = sex DISCRETE;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC SGPLOT DATA = class;
    TITLE
      "PROC SGPLOT: Stacked horizontal barchart of CLASS";
    HBAR age / GROUP = sex;
    KEYLEGEND;  /*WPS*/
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC GCHART DATA = class;
    TITLE
      "PROC GCHART: Clustered horizontal barchart of CLASS";
    HBAR sex / GROUP = age
               PATTERNID = MIDPOINT;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY sex age;
RUN;

PROC SGPLOT DATA = class;
    TITLE
      "PROC SGPLOT: Clustered horizontal barchart of CLASS";
    HBAR age / GROUP = sex
               GROUPDISPLAY = CLUSTER;
    KEYLEGEND;  /*WPS*/
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY age;
RUN;

PROC GCHART DATA = class;
    PIE age / VALUE = ARROW
              /*LEGEND*/ DISCRETE;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY age;
RUN;

PROC TEMPLATE;
  DEFINE STATGRAPH pie;
    BEGINGRAPH;
      LAYOUT REGION;
        PIECHART CATEGORY = age /
          DATALABELLOCATION = OUTSIDE
          CATEGORYDIRECTION = CLOCKWISE
          START = 180 NAME = 'pie';
        DISCRETELEGEND 'pie' /
          TITLE = 'Age';
      ENDLAYOUT;
    ENDGRAPH;
  END;
RUN;

PROC SGRENDER DATA = class TEMPLATE = pie;
RUN;

*-------------------------------------------------*;

PROC SORT DATA = sashelp9.class
          OUT = class;
    BY age;
RUN;

PROC SGPIE DATA = class;
    TITLE "PROC SGPIE: Pie chart of CLASS";
    PIE age / STAT = FREQ STARTANGLE = 0
              DATALABELLOCATION = OUTSIDE
              CATEGORYDIRECTION = COUNTERCLOCKWISE;
    KEYLEGEND;
RUN;
