LIBNAME new 'c:\temp\new';
PROC DATASETS LIB = new KILL;
RUN;
QUIT;
DATA sasuser.v_prdsale / VIEW = sasuser.v_prdsale;
  SET sashelp.prdsale;
  LENGTH yyq $6;
  yyqtr = year + (quarter - 1)/4;
  mon = MONTH(month);
  yyq = PUT(month, YYQ6.);
  yq = INTCK('QTR', '31dec1992'd, month);
  SELECT (country);
    WHEN ('U.S.A.') cntry = 'USA';
    WHEN ('GERMANY') cntry = 'DE';
    WHEN ('CANADA') cntry = 'CA';
    OTHERWISE;
  END;
RUN;
PROC SUMMARY DATA = sasuser.v_prdsale MISSING NWAY;
  CLASS cntry yq product;
  VAR actual;
  OUTPUT OUT = new.prdsale SUM =;
RUN;

*-----------------------------------------------------*;

/* Macro exportlib
  Usage: %exportlib(lib, outdir, tempdir);
  Arguments:
    lib - SAS libname for input datasets
    outdir - directory in which to write .csv files
      (default ".")
    tempdir - temporary directory to hold generated
      SAS code (default C:/WINDOWS/TEMP)
*/
%MACRO exportlib(lib, outdir, tempdir);
  %IF %QUOTE(&outdir)= %THEN %LET outdir=.;
  %IF %QUOTE(&tempdir)=
    %THEN %LET tempdir=C:/WINDOWS/TEMP;
  OPTIONS NOFMTERR;
  PROC COPY IN=&lib OUT=work;
  RUN;
  PROC CONTENTS DATA = work._ALL_ NOPRINT
    OUT = _contents_(KEEP = memname memlabel name type
                            label format length nobs);
  RUN;
  PROC EXPORT DATA = _contents_
    OUTFILE = "&outdir/_contents_.csv" REPLACE;
  RUN;
  DATA _NULL_;
    SET _contents_;
    BY memname;
    FILE "&tempdir/_export_.sas";
    RETAIN bk -1;
    IF FIRST.memname & (nobs > 0) THEN DO;
      PUT 'DATA ' memname ';';
      PUT ' SET ' memname ';';
      PUT ' FORMAT _NUMERIC_ BEST14.;';
      PUT 'RUN;';
      PUT 'PROC EXPORT DATA = ' memname;
      PUT ' OUTFILE = "' "&outdir/" memname
          +bk '.csv"';
      PUT ' REPLACE;';
      PUT 'RUN;';
    END;
  RUN;
  %INCLUDE "&tempdir/_export_.sas";
%MEND exportlib;
PROC FORMAT CNTLOUT = _cntlout;
RUN;
%exportlib(new, c:/temp/r, c:/windows/temp);

*-----------------------------------------------------*;

DATA _NULL_;
  FILE 'c:\temp\r\program.r' LRECL = 1024;
  PUT 'library(Hmisc)';
  PUT 'library(lattice)';
  PUT 'library(grDevices)';
  PUT "sasdata <- sasxport.get('c:/temp/r',";
  PUT "  method=('csv'))";
  PUT "trellis.device(jpeg,
         file='c:/temp/r/program.jpg',";
  PUT '  width=480, height=480)';
  PUT 'trellis.par.set(theme=col.whitebg())';
  PUT "trellis.par.set('background',
       list(col='white'))";
  PUT "trellis.par.set('plot.symbol',
       list(col='blue'))";
  PUT "trellis.par.set('dot.symbol',
       list(col='blue'))";
  PUT "trellis.par.set('axis.line', list(col='red'))";
  PUT "trellis.par.set('box.rectangle',
                       list(col='red'))";
  PUT "trellis.par.set('par.xlab.text',
                       list(col='green'))";
  PUT "trellis.par.set('par.ylab.text',
                       list(col='green'))";
  PUT "trellis.par.set('par.zlab.text',
                       list(col='green'))";
  PUT "trellis.par.set('axis.text',
                       list(col='green'))";
  PUT 'xyplot(actual ~ yq | product*cntry,';
  PUT '  data=sasdata$prdsale,';
  PUT "  xlab = 'Quarter',";
  PUT "  ylab = 'Actual Sales',";
  PUT '  panel = function(x, y) {';
  PUT '    panel.grid(h=-1, v=-1)';
  PUT '    panel.xyplot(x, y)';
  PUT '    panel.loess(x, y,';
  PUT '      span=1,';
  PUT '      degree=2';
  PUT '    )';
  PUT '  },';
  PUT "  main = 'Plotted using R'";
  PUT ')';
  PUT 'dev.off()';
  PUT 'q()';
RUN;

*-----------------------------------------------------*;

OPTIONS XWAIT XSYNC;
X "r.exe --no-save --quiet <""c:\temp\r\program.r""
  >""c:\temp\r\program.log""";
  
*-----------------------------------------------------*;

DATA _NULL_;
  INFILE 'c:\temp\r\program.log';
  FILE LOG;
  INPUT;
  PUT '**R: ' _INFILE_;
RUN;

ODS ESCAPECHAR = '^';
ODS HTML FILE = 'c:\temp\r\report.html'
         STYLE = minimal GPATH = 'c:\temp\r'
         GTITLE GFOOTNOTE;

DATA _NULL_;
  FILE PRINT;
  PUT "<IMG SRC='c:\temp\r\program.jpg' BORDER='0'>";
RUN;

ODS ESCAPECHAR = '^';
ODS RTF FILE = 'c:\temp\r\report.rtf' STYLE = minimal
        GTITLE GFOOTNOTE;

DATA _NULL_;
  FILE PRINT;
  PUT "^S={PREIMAGE='c:\temp\r\program.jpg'}";
RUN;

ODS _ALL_ CLOSE;